0.9.9 API documentation: GLM_EXT_quaternion_relational

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_EXT_quaternion_relational
Stable extensions

Exposes comparison functions for quaternion types that take a user defined epsilon values. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | equal (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison of result x == y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | equal (qua< T, Q > const &x, qua< T, Q > const &y, T epsilon)
| Returns the component-wise comparison of |x - y| < epsilon. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | notEqual (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison of result x != y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | notEqual (qua< T, Q > const &x, qua< T, Q > const &y, T epsilon)
| Returns the component-wise comparison of |x - y| >= epsilon. More...

## Detailed Description

Exposes comparison functions for quaternion types that take a user defined epsilon values.

Include <glm/ext/quaternion_relational.hpp> to use the features of this extension.

See also
  core_vector_relational
  GLM_EXT_vector_relational
  GLM_EXT_matrix_relational
  GLM_EXT_quaternion_float
  GLM_EXT_quaternion_double

## Function Documentation

GLM_FUNC_DECL vec<4, bool, Q> glm::equal | ( | qua< T, Q > const & | x,
|  | qua< T, Q > const & | y
| ) |  |

Returns the component-wise comparison of result x == y.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

GLM_FUNC_DECL vec<4, bool, Q> glm::equal | ( | qua< T, Q > const & | x,
|  | qua< T, Q > const & | y,
|  | T | epsilon
| ) |  |

Returns the component-wise comparison of |x - y| < epsilon.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

GLM_FUNC_DECL vec<4, bool, Q> glm::notEqual | ( | qua< T, Q > const & | x,
|  | qua< T, Q > const & | y
| ) |  |

Returns the component-wise comparison of result x != y.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

GLM_FUNC_DECL vec<4, bool, Q> glm::notEqual | ( | qua< T, Q > const & | x,
|  | qua< T, Q > const & | y,
|  | T | epsilon
| ) |  |

Returns the component-wise comparison of |x - y| >= epsilon.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum